@@ -9,8 +9,8 @@ def casing():
     #Chama os pacotes usados no programa
     import math
    # import matplotlib.pyplot  #Necessário somente caso for construir o gráfico, entretanto o gráfico não é necessário
-   # from RocketCasing import materials
-    import materials
+    from RocketCasing import materials
+   #import materials
     from datetime import datetime
 
 #Abertura do programa
